package com.qihoo360.mobilesafe.service;

import com.qihoo360.mobilesafe.service.IAttention;
import com.qihoo360.mobilesafe.service.ProcessInfo;
import com.qihoo360.mobilesafe.service.ProcessFilter;
import com.qihoo360.mobilesafe.service.UserDecision;
import com.qihoo360.mobilesafe.service.GarbageInfo;

interface ISysClear {
    void registerAttention(IAttention atta);
    void unRegisterAttention(IAttention atta);

    /**
     * 读取系统进程清理白名单（360手机桌面接口）
     * 其中Map<k, v>中 k为应用包名，v为是否清理标志；详情参考 UserDecision 中的userSelection
     */
    Map getUserDecision();

    /**
     * 获取系统总可用内存，单位: MB（360手机桌面接口）
     */
    int getMemoryTotal();

    /**
     * 获取系统剩余内存，单位: MB（360手机桌面接口）
     */
    int getMemoryFree();

    /**
     * 设置系统进程清理白名单
     * @param processFilter 白名单列表
     */
    void setProcessFilter(in List<ProcessFilter> processFilters);

    /**
     * 设置用户选择信息
     * @param userDecisions 用户选择列表
     */    
    void setUserDecision(in List<UserDecision> userDecisions);

    /**
     * 保存用户选择信息
     * @param userDecision 用户选择
     */    
    void saveUserDecision(in UserDecision userDecision);

    /**
     * 重新加载当前运行进程信息或垃圾信息
     * @param includeProcessInfo 是否重新加载进程信息, true为重新加载
     * @param includeGarbageInfo 是否重新加载垃圾信息, true为重新加载
     */
    void reloadSysInfo(boolean includeProcessInfo, boolean includeGarbageInfo);

    /**
     * 重新加载当前运行进程信息或垃圾信息
     * @param includeProcessInfo 是否重新加载进程信息, true为重新加载
     * @param includeGarbageInfo 是否重新加载垃圾信息, true为重新加载
     * @param maxGarbageCount 加载垃圾信息时，扫描文件的上限，超过上限停止扫描。0表示无上限
     */
    void reloadSysInfoWithLimit(boolean includeProcessInfo, boolean includeGarbageInfo, int maxGarbageCount);

    /**
     * 获取进程信息
     */
    List<ProcessInfo> getProcessList();

    /**
     * 开始清理指定的进程
     * @param packages 需要清理的进程列表
     */
    void beginKillProcess(in List<String> packages);

    /**
     * 一键清理，只清理用户默认选中的进程
     */
    void beginKillUserProcess();

    /**
      * 一键清理，只清理用户默认选中的进程
      * @param applyRoot 如果未获取root权限,是否尝试申请root权限进行清理
      */
    void beginKillProcessApplyRoot(boolean applyRoot);

    /**
     * 取消清理进程 
     */
    void cancelKillProcess();

    /** 
     * 当前处理的状态
     * return 0：空闲；1: 正在加载数据； 2：正在清理进程；3：正在清理垃圾文件；4：正在清理启动项；
     */
    int getStatus();

    /**
     * 最近是否清理了进程 
     */
    boolean isKillProcessRecently();

    /**
     * 获取垃圾信息
     */
    List<GarbageInfo> getGarbageList();

    /**
     * 垃圾文件数量
     */
    int getGarbageFileCount();

    /**
     * 一键清理，清理程序的垃圾文件
     */
    void beginClearGarbage();

    /**
     * 取消清理垃圾文件
     */
    void cancelClearGarbage();

    /**
     * 重新加载配置信息，用于下载升级新配置文件后调用
     */
    void reloadConfig();

    /**
     *   更新一条垃圾清理项
     */
    void refreshGarbageInfo(String packageName, long cacheSize);
}